| rmix | R Documentation |
Random generation for the well-known mixture models with parameters weigth, shape and scale.
rmix(N, model, K, param)
N |
Number of inputs for the mixture random generation |
model |
Choice of one of the mixture models; |
K |
Number of components |
param |
Vector of weight |
Outputs of random generated vector lenght of N from the given mixture model.
N<-100
K<-2
weight<-c(0.5,0.5)
alpha<-c(0.5,1)
beta<-c(1,0.5)
param<-c(weight,alpha,beta)
rmix(N, "weibull", K, param)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.