| dmix | R Documentation |
Computing probability density function for the well-known mixture models.
dmix(lifespan, model, K, param)
lifespan |
Vector of samples |
model |
choice of one of the mixture models; |
K |
number of components |
param |
Vector of weight |
A vector of the same length as lifespan data, given the pdf of the one of the mixture models computed at lifespan.
lifespan<-seq(0,30,0.2)
K<-2
weight<-c(0.6,0.4)
alpha<-c(0.5,1)
beta<-c(1,0.5)
param<-c(weight,alpha,beta)
dmix(lifespan, "log-logistic", K, param)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.